@@ -1,7 +1,10 @@
 package Kephra::API::EventTable;
-$VERSION = '0.08';
+$VERSION = '0.09';
+
+=head1
+
+Kephra::API::EventTable - Kephra's API to internal events
 
-=pod
  internal app events handling
  events call functions that subscribed to that event
  other function can trigger events
@@ -13,8 +16,11 @@ $VERSION = '0.08';
 use strict;
 use Wx qw( wxSTC_CMD_NEWLINE WXK_RETURN );
 use Wx::Event qw(
+	EVT_TIMER EVT_IDLE
 	EVT_KEY_UP EVT_KEY_DOWN
-	EVT_ENTER_WINDOW EVT_LEAVE_WINDOW EVT_CLOSE EVT_DROP_FILES EVT_MENU_OPEN
+	EVT_LEFT_UP EVT_LEFT_DOWN EVT_MOTION
+	EVT_ENTER_WINDOW EVT_LEAVE_WINDOW EVT_CLOSE 
+	EVT_DROP_FILES EVT_MENU_OPEN
 	EVT_STC_CHANGE EVT_STC_UPDATEUI EVT_STC_MARGINCLICK
 	EVT_STC_SAVEPOINTREACHED EVT_STC_SAVEPOINTLEFT
 );
@@ -23,18 +29,24 @@ use Wx::Event qw(
 # get pointer to the event list
 sub _get_active { $Kephra::app{eventtable} }
 sub _get_frozen { $Kephra::temp{eventtable} }
+my  $timer;
 
 
 sub connect_all {
-	my $win = Kephra::App::Window::_get();
-	my $ep  = Kephra::App::EditPanel::_get();
-	$Kephra::app{eventtable}{test} = 1;
-	$Kephra::temp{eventtable}{test} = 1;
+	my $win = Kephra::App::Window::_ref();
+	my $ep  = Kephra::App::EditPanel::_ref();
+	my $tb  = Kephra::App::TabBar::_ref();
+	#$Kephra::app{eventtable}{test} = 1;
+	#$Kephra::temp{eventtable}{test} = 1;
 
 	# events for whole window
 	EVT_CLOSE      ($win,  sub { trigger('app.close'); Kephra::quit() });
 	EVT_DROP_FILES ($win,  \&Kephra::File::add_dropped);
-	EVT_MENU_OPEN  ($win,  sub { trigger('menu.open') });
+	EVT_MENU_OPEN  ($win,  sub {
+#print"menu ",$_[1]->GetMenuId, ' ', $_[1]->GetMenu, "\n";
+		trigger('menu.open') });
+	#EVT_IDLE       ($win,  sub { } );
+
 
 
 	# scintilla and editpanel events
@@ -43,6 +55,11 @@ sub connect_all {
 	init_key_events();
 	EVT_DROP_FILES ($ep,   \&Kephra::File::add_dropped); # override sci presets
 
+	# TabBar
+	#EVT_LEFT_UP();
+	#EVT_MOTION();
+	#EVT_LEFT_DOWN();
+
 	EVT_ENTER_WINDOW ($ep,   sub {
 		Wx::Window::SetFocus( $ep ) unless $Kephra::temp{dialog}{active};
 		trigger('editpanel.focus');
@@ -54,10 +71,42 @@ sub connect_all {
 	EVT_STC_MARGINCLICK     ($ep, -1, sub {
 		#Kephra::Dialog::msg_box(undef, "a", 'b')
 	});
+
+	start_timer();
 }
 
+
+sub start_timer {
+	# set or update timer events
+	my $win = Kephra::App::Window::_ref();
+
+	stop_timer();
+	if ($Kephra::config{file}{save}{auto_save}) {
+		$timer->{file_save} = Wx::Timer->new( $win, 1 );
+		$timer->{file_save}->Start
+			( $Kephra::config{file}{save}{auto_save} * 1000 );
+		EVT_TIMER( $win, 1, sub { Kephra::File::save_all_named() } );
+	}
+
+	if ($Kephra::config{file}{open}{notify_change}) {
+		$timer->{file_notify} = Wx::Timer->new( $win, 2 );
+		$timer->{file_notify}->Start
+			( $Kephra::config{file}{open}{notify_change} * 1000 );
+		EVT_TIMER( $win, 2, sub { Kephra::File::changed_notify_check() } );
+	}
+}
+
+sub stop_timer {
+	my $win = Kephra::App::Window::_ref();
+	$timer->{file_save}->Stop if ref $timer->{file_save} eq 'Wx::Timer';
+	delete $timer->{file_save};
+	$timer->{file_notify}->Stop if ref $timer->{file_notify} eq 'Wx::Timer';
+	delete $timer->{file_notify};
+}
+
+
 sub connect_editpanel{
-	my $ep  = Kephra::App::EditPanel::_get();
+	my $ep  = Kephra::App::EditPanel::_ref();
 
 	EVT_STC_CHANGE ($ep, -1, sub {
 		my ( $ep, $event ) = @_;
@@ -77,25 +126,23 @@ sub connect_editpanel{
 }
 
 sub disconnect_editpanel{
-	my $ep  = Kephra::App::EditPanel::_get();
+	my $ep  = Kephra::App::EditPanel::_ref();
 
 	EVT_STC_CHANGE  ($ep, -1, sub {});
 	EVT_STC_UPDATEUI($ep, -1, sub {});
 }
 
-sub init_key_events{
- my $stc    = Kephra::App::EditPanel::_get();
+sub init_key_events {
 
-	EVT_KEY_DOWN  ($stc,     sub {
+	EVT_KEY_DOWN  (Kephra::App::EditPanel::_ref(), sub {
 		my ($ep, $event) = @_;
-
-		my $map = $Kephra::app{editpanel}{keymap};
 		my $key = $event->GetKeyCode +
 			1000 * ($event->ShiftDown + $event->ControlDown*2 + $event->AltDown*4);
 
-		if (ref $map->[$key] eq 'CODE'){
-			$map->[$key]();
-		} elsif ($key ==  WXK_RETURN) { # Enter
+		# reacting on shortkeys that are defined in the Commanlist
+		return if Kephra::API::CommandList::run_cmd_by_keycode($key);
+		# reacting on Enter
+		if ($key ==  WXK_RETURN) { # Enter
 			if ($Kephra::config{editpanel}{auto}{brace}{indention}) {
 				my $pos  = $ep->GetCurrentPos - 1;
 				my $char = $ep->GetCharAt($pos);
@@ -108,10 +155,12 @@ sub init_key_events{
 			$Kephra::config{editpanel}{auto}{indention}
 				? Kephra::Edit::Format::autoindent()
 				: $ep->CmdKeyExecute(wxSTC_CMD_NEWLINE) ;
-		} else { $event->Skip }
+		}
+		# scintilla handles the rest of the shortkeys
+		else { $event->Skip }
 		#Kephra::App::Visual::status_msg();
 		#SCI_SETSELECTIONMODE
-		#($key == 350){use Kephra::Ext::Perl::Syntax;  Kephra::Ext::Perl::Syntax::check()};
+		#($key == 350){use Kephra::Ext::Perl::Syntax; Kephra::Ext::Perl::Syntax::check()};
 	});
 }
 
